Examples Gallery
*******************************************************************************

We provide several examples for using `YAHPO Gym`:

- `General Usage <https://github.com/slds-lmu/yahpo_gym/blob/main/yahpo_gym/notebooks/using_yahpo_gym.ipynb>`_

- `Tuning with HpBandSter on Yahpo Gym <https://github.com/slds-lmu/yahpo_gym/blob/main/yahpo_gym/notebooks/tuning_hpandster_on_yahpo.ipynb>`_

- `Transfer HPO <https://github.com/slds-lmu/yahpo_gym/blob/main/yahpo_gym/notebooks/transfer_example.ipynb>`_

- `Paper Examples <https://github.com/slds-lmu/yahpo_gym/blob/main/yahpo_gym/notebooks/code_sample.ipynb>`_

- `Paper Experiments <https://github.com/slds-lmu/yahpo_exps/tree/main/paper>`_
